klar

package
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 9, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Logger

type Logger struct {
	*log.Logger
}

Logger is a wrapper around the charm log package with json log parsing

func New

func New(w io.Writer, level log.Level) Logger

New creates a new Logger with some opinionated defaults

func (Logger) Decode

func (l Logger) Decode(ctx context.Context, r io.Reader) error

Decode reads structured JSON logs and writes them as human-readable logs

Jump to